@@ -6,7 +6,7 @@
 prefix=/usr/local
 exec_prefix=${prefix}
 libdir=${exec_prefix}/lib
-classpath=${prefix}/share/java/gconf2.8-2.8.3.1.jar
+classpath=${prefix}/share/java/gconf2.9-2.9.3.jar
 
 GCONFJAVA_LIB=$libdir
 GCONFJAVA_JAR=$classpath
