@@ -14,6 +14,7 @@ import java.util.List;
 import java.util.Vector;
 
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 
 /**
  * ConfClient provides a client-side cache for a specified list of directories
@@ -37,7 +38,7 @@ public class ConfClient extends GObject {
 	 */
 	private Hashtable listeners = null;
 	
-	private ConfClient(int handle) {
+	private ConfClient(Handle handle) {
 		super(handle);
 	}
 	
@@ -172,7 +173,7 @@ public class ConfClient extends GObject {
 	 */
 	public ConfValue get(String key) throws ConfException {
 		int err = -1;
-		int hndl = gconf_client_get(getHandle(), key, new int[] {err});
+		Handle hndl = gconf_client_get(getHandle(), key, new int[] {err});
 		checkError(err);
 		return new ConfValue(hndl);
 	}
@@ -187,7 +188,7 @@ public class ConfClient extends GObject {
 	 */
 	public ConfEntry getEntry(String key, String locale, boolean useSchemaDefault) throws ConfException {
 		int err = -1;
-		int hndl = gconf_client_get_entry(getHandle(), key, locale, useSchemaDefault, new int[] {err});
+		Handle hndl = gconf_client_get_entry(getHandle(), key, locale, useSchemaDefault, new int[] {err});
 		checkError(err);
 		return new ConfEntry(hndl);
 	}
@@ -202,7 +203,7 @@ public class ConfClient extends GObject {
 	 */
 	public ConfValue getDefaultFromSchema(String key) throws ConfException {
 		int err = -1;
-		int hndl = gconf_client_get_default_from_schema(getHandle(), key, new int[] {err});
+		Handle hndl = gconf_client_get_default_from_schema(getHandle(), key, new int[] {err});
 		checkError(err);
 		return new ConfValue(hndl);
 	}
@@ -228,7 +229,7 @@ public class ConfClient extends GObject {
 	 */
 	public List getAllEntries(String dir) throws ConfException {
 		int err = -1;
-		int [] array = gconf_client_all_entries(getHandle(), dir, new int[] {err});
+		Handle [] array = gconf_client_all_entries(getHandle(), dir, new int[] {err});
 		checkError(err);
 		if (array == null)
 			return null;
@@ -342,7 +343,7 @@ public class ConfClient extends GObject {
 	 */
 	public ConfSchema getSchema(String key) throws ConfException {
 		int err = -1;
-		int ret = gconf_client_get_schema(getHandle(), key, new int[] {err});
+		Handle ret = gconf_client_get_schema(getHandle(), key, new int[] {err});
 		checkError(err);
 		return new ConfSchema(ret);
 	}
@@ -442,7 +443,7 @@ public class ConfClient extends GObject {
 		return false;
 	}
 	
-	protected void notifyCallback(int e, String nameSpace) {
+	protected void notifyCallback(Handle e, String nameSpace) {
 		NotifyData nd = (NotifyData)listeners.get(nameSpace);
 		if (null == nd)
 			return;
@@ -461,45 +462,41 @@ public class ConfClient extends GObject {
 			throw new ConfException(error);
 	}
 
-	/****************************************
-	 * BEGINNING OF NATIVE CODE
-	 ****************************************/
-	native static final protected int gconf_client_get_default();
-	native static final protected int gconf_client_get_for_engine(int engine);
-	native static final protected void gconf_client_add_dir(int client, String dir, int preloadType, int[] error);
-	native static final protected void gconf_client_remove_dir(int client, String dir, int[] error);
-	native final protected int gconf_client_notify_add(int client, String namespace, int[] error);
-	native static protected void gconf_client_notify_remove(int client, int cnxn);
-	native static final protected void gconf_client_clear_cache(int client);
-	native static final protected void gconf_client_preload(int client, String dirname, int type, int[] error);
-	native static final protected void gconf_client_set(int client, String key, int val, int[] error);
-	native static final protected int gconf_client_get(int client, String key, int[] error);
-	native static final protected int gconf_client_get_without_default(int client, String key, int[] error);
-	native static final protected int gconf_client_get_entry(int client, String key, String locale, boolean useSchemaDefault, int[] error);
-	native static final protected int gconf_client_get_default_from_schema(int client, String key, int[] error);
-	native static final protected boolean gconf_client_unset(int client, String key, int[] error);
-	native static final protected int[] gconf_client_all_entries(int client, String dir, int[] error);
-	native static final protected String[] gconf_client_all_dirs(int client, String dir, int[] error);
-	native static final protected void gconf_client_suggest_sync(int client, int[] error);
-	native static final protected boolean gconf_client_dir_exists(int client, String dir, int[] error);
-	native static final protected double gconf_client_get_float(int client, String key, int[] error);
-	native static final protected int gconf_client_get_int(int client, String key, int[] error);
-	native static final protected String gconf_client_get_string(int client, String key, int[] error);
-	native static final protected boolean gconf_client_get_bool(int client, String key, int[] error);
-	native static final protected int gconf_client_get_schema(int client, String key, int[] error);
-	native static final protected Object[] gconf_client_get_list(int client, String key, int listType, int[] error);
-	native static final protected boolean gconf_client_get_pair(int client, String key, int carType, int cdrType, int[] car, int[] cdr, int[] error);
-	native static final protected boolean gconf_client_set_float(int client, String key, double val, int[] error);
-	native static final protected boolean gconf_client_set_int(int client, String key, int val, int[] error);
-	native static final protected boolean gconf_client_set_string(int client, String key, String val, int[] error);
-	native static final protected boolean gconf_client_set_bool(int client, String key, boolean val, int[] error);
-	native static final protected boolean gconf_client_set_schema(int client, String key, int val, int[] error);
-	native static final protected boolean gconf_client_set_list(int client, String key, int listType, Object[] list, int[] error);
-	native static final protected boolean gconf_client_set_pair(int client, String key, int carType, int cdrType, int car, int cdr, int[] error);
-	native static final protected void gconf_client_value_changed(int client, String key, int value);
-	/****************************************
-	 * END OF NATIVE CODE
-	 ****************************************/
+
+	native static final protected Handle gconf_client_get_default();
+	native static final protected Handle gconf_client_get_for_engine(Handle engine);
+	native static final protected void gconf_client_add_dir(Handle client, String dir, int preloadType, int[] error);
+	native static final protected void gconf_client_remove_dir(Handle client, String dir, int[] error);
+	native final protected int gconf_client_notify_add(Handle client, String namespace, int[] error);
+	native static protected void gconf_client_notify_remove(Handle client, int cnxn);
+	native static final protected void gconf_client_clear_cache(Handle client);
+	native static final protected void gconf_client_preload(Handle client, String dirname, int type, int[] error);
+	native static final protected void gconf_client_set(Handle client, String key, Handle val, int[] error);
+	native static final protected Handle gconf_client_get(Handle client, String key, int[] error);
+	native static final protected Handle gconf_client_get_without_default(Handle client, String key, int[] error);
+	native static final protected Handle gconf_client_get_entry(Handle client, String key, String locale, boolean useSchemaDefault, int[] error);
+	native static final protected Handle gconf_client_get_default_from_schema(Handle client, String key, int[] error);
+	native static final protected boolean gconf_client_unset(Handle client, String key, int[] error);
+	native static final protected Handle[] gconf_client_all_entries(Handle client, String dir, int[] error);
+	native static final protected String[] gconf_client_all_dirs(Handle client, String dir, int[] error);
+	native static final protected void gconf_client_suggest_sync(Handle client, int[] error);
+	native static final protected boolean gconf_client_dir_exists(Handle client, String dir, int[] error);
+	native static final protected double gconf_client_get_float(Handle client, String key, int[] error);
+	native static final protected int gconf_client_get_int(Handle client, String key, int[] error);
+	native static final protected String gconf_client_get_string(Handle client, String key, int[] error);
+	native static final protected boolean gconf_client_get_bool(Handle client, String key, int[] error);
+	native static final protected Handle gconf_client_get_schema(Handle client, String key, int[] error);
+	native static final protected Object[] gconf_client_get_list(Handle client, String key, int listType, int[] error);
+	native static final protected boolean gconf_client_get_pair(Handle client, String key, int carType, int cdrType, int[] car, int[] cdr, int[] error);
+	native static final protected boolean gconf_client_set_float(Handle client, String key, double val, int[] error);
+	native static final protected boolean gconf_client_set_int(Handle client, String key, int val, int[] error);
+	native static final protected boolean gconf_client_set_string(Handle client, String key, String val, int[] error);
+	native static final protected boolean gconf_client_set_bool(Handle client, String key, boolean val, int[] error);
+	native static final protected boolean gconf_client_set_schema(Handle client, String key, Handle val, int[] error);
+	native static final protected boolean gconf_client_set_list(Handle client, String key, int listType, Object[] list, int[] error);
+	native static final protected boolean gconf_client_set_pair(Handle client, String key, int carType, int cdrType, int car, int cdr, int[] error);
+	native static final protected void gconf_client_value_changed(Handle client, String key, Handle value);
+
 
 	static {
 		System.loadLibrary("gconfjava2.9");
